#ifndef EPAPER_H
#define EPAPER_H


#include <stdio.h>
#include <inttypes.h>
#include "driver/gpio.h"
#include "esp_log.h"
#include "esp_system.h"

#include "spi.h"

#define EPD_CS_PIN    34
#define EPD_DC_PIN    35  
#define EPD_BUSY_PIN  37
#define EPD_RST_PIN   16

/********************* 屏幕参数定义 *********************/
#define EPD_WIDTH     320     // 屏幕宽度
#define EPD_HEIGHT    240     // 屏幕高度
#define EPD_BUFFER_SIZE  ((EPD_WIDTH * EPD_HEIGHT) / 8)  // 显存大小（1bit/像素）

/********************* 指令集定义 *********************/
#define PANEL_SETTING                               0x00
#define POWER_SETTING                               0x01
#define POWER_OFF                                   0x02
#define POWER_OFF_SEQUENCE_SETTING                  0x03
#define POWER_ON                                    0x04
#define POWER_ON_MEASURE                            0x05
#define BOOSTER_SOFT_START                          0x06
#define DEEP_SLEEP                                  0x07
#define DATA_START_TRANSMISSION_1                   0x10
#define DATA_STOP                                   0x11
#define DISPLAY_REFRESH                             0x12
#define DATA_START_TRANSMISSION_2                   0x13
#define PLL_CONTROL                                 0x30
#define TEMPERATURE_SENSOR_COMMAND                  0x40
#define TEMPERATURE_SENSOR_CALIBRATION              0x41
#define TEMPERATURE_SENSOR_WRITE                    0x42
#define TEMPERATURE_SENSOR_READ                     0x43
#define VCOM_AND_DATA_INTERVAL_SETTING              0x50
#define LOW_POWER_DETECTION                         0x51
#define TCON_SETTING                                0x60
#define TCON_RESOLUTION                             0x61
#define SOURCE_AND_GATE_START_SETTING               0x62
#define GET_STATUS                                  0x71
#define AUTO_MEASURE_VCOM                           0x80
#define READ_VCOM_VALUE                             0x81
#define VCM_DC_SETTING_REGISTER                     0x82
#define PARTIAL_WINDOW                              0x90
#define PARTIAL_IN                                  0x91
#define PARTIAL_OUT                                 0x92
#define PROGRAM_MODE                                0xA0
#define ACTIVE_PROGRAM                              0xA1
#define READ_OTP_DATA                               0xA2
#define POWER_SAVING                                0xE3


esp_err_t epd_init();
esp_err_t epd_clear(uint8_t color);
void epd_draw_point(uint16_t x, uint16_t y, uint8_t color);
esp_err_t epd_refresh(void);
void epd_sleep(void);
uint8_t *epd_get_buffer(void);

#endif