/*
 * SPDX-FileCopyrightText: 2010-2022 Espressif Systems (Shanghai) CO LTD
 *
 * SPDX-License-Identifier: CC0-1.0
 */

#include <stdio.h>
#include <inttypes.h>
#include "sdkconfig.h"
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "esp_chip_info.h"
#include "esp_flash.h"
#include "esp_system.h"

#include "esp_spiffs.h"
#include "esp_log.h"
#include "esp_timer.h"

#include "spiffs.h"
#include "spi.h"
#include "epaper.h"

static const char *TAG = "SYS";

void app_main(void)
{
    ESP_LOGI(TAG, "Hello world!");

    /* Print chip information */
    esp_chip_info_t chip_info;
    uint32_t flash_size;
    esp_chip_info(&chip_info);
    ESP_LOGI(TAG, "This is %s chip with %d CPU core(s), %s%s%s%s, ",
             CONFIG_IDF_TARGET,
             chip_info.cores,
             (chip_info.features & CHIP_FEATURE_WIFI_BGN) ? "WiFi/" : "",
             (chip_info.features & CHIP_FEATURE_BT) ? "BT" : "",
             (chip_info.features & CHIP_FEATURE_BLE) ? "BLE" : "",
             (chip_info.features & CHIP_FEATURE_IEEE802154) ? ", 802.15.4 (Zigbee/Thread)" : "");

    unsigned major_rev = chip_info.revision / 100;
    unsigned minor_rev = chip_info.revision % 100;
    ESP_LOGI(TAG, "silicon revision v%d.%d, ", major_rev, minor_rev);
    if (esp_flash_get_size(NULL, &flash_size) != ESP_OK)
    {
        ESP_LOGI(TAG, "Get flash size failed");
        return;
    }

    ESP_LOGI(TAG, "%" PRIu32 "MB %s flash", flash_size / (uint32_t)(1024 * 1024),
             (chip_info.features & CHIP_FEATURE_EMB_FLASH) ? "embedded" : "external");

    ESP_LOGI(TAG, "Minimum free heap size: %" PRIu32 " bytes", esp_get_minimum_free_heap_size());

    ESP_LOGI(TAG, "sizeof(int) ==%d", sizeof(int));

    // 内部 RAM 信息
    size_t internal_free = heap_caps_get_free_size(MALLOC_CAP_INTERNAL);
    size_t internal_total = heap_caps_get_total_size(MALLOC_CAP_INTERNAL);

    ESP_LOGI(TAG,"内部 RAM 总大小：%u KB，可用：%u KB", internal_total/1024, internal_free/1024);

    // PSRAM 信息
    size_t psram_free = heap_caps_get_free_size(MALLOC_CAP_SPIRAM);
    size_t psram_total = heap_caps_get_total_size(MALLOC_CAP_SPIRAM);

    ESP_LOGI(TAG,"PSRAM 总大小：%u KB，可用：%u KB", psram_total/1024, psram_free/1024);

    spi_init();
    epd_init();
    //epd_clear(1);
    // // 3. 画测试点（黑色）
    // epd_draw_point(50, 50, 0);   // (50,50) 黑点
    // epd_draw_point(50, 60, 0);   // (50,60) 黑点
    // epd_draw_point(60, 50, 0);   // (60,50) 黑点
    // epd_draw_point(60, 60, 0);   // (60,60) 黑点

    // // 4. 刷新屏幕
    // epd_refresh();


    // 1. 初始化 SPIFFS
    const char *spiffs_base_path = "/spiffs";
    esp_err_t ret = spiffs_init(spiffs_base_path);

    if (ret != ESP_OK)
    {
        ESP_LOGE(TAG, "SPIFFS 初始化失败");
    }
    else
    {
        ESP_LOGI(TAG, "SPIFFS 初始化OK");

        list_spiffs_files_safe(spiffs_base_path);
    }

    while(1)
    {

        vTaskDelay(1); // 必须让出CPU
    }



}
